#!/usr/bin/env python3
"""
Random Generator.

by BBaoVanC

Generates a name by using random characters!

Examples:
    KkC44zZIkJ6b
    Mw6xAKYulItJ
    qK1Kpv89fJj1

Copyright (C) 2020 BBaoVanC
"""

# Imports
import random
import libprogress


# Generation method
def gen(count=1, debug=False, length=12):
    """
    Generate names using the random method.

    Arguments:
    count -- the amount of names to generate (default 1)
    debug -- whether debug should be printed (default False)
    """
    names = list()  # prepare blank names list
    n = 1  # prepare loop counter

    while count >= n:
        name = ""  # prepare name variable
        for _ in range(length):  # for each chracter in the name
            charset = ["a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k",
                       "l", "m", "n", "o", "p", "q", "r", "s", "t", "u", "v",
                       "w", "x", "y", "z", "_", "0", "1", "2", "3", "4", "5",
                       "6", "7", "8", "9"]  # character set
            char = random.choice(charset)  # nosec | choose a random character
            cap = random.choice([True, False])  # nosec | choose capitalization
            if cap:  # if it should be capitalized
                char = char.capitalize()  # capitalize the letter
            name = name + str(char)  # add the character to the name
        if debug:  # if we should output debug information
            # print progress bar for generating names
            print(libprogress.genbar(curprg=n-1, maxprg=count), end="\r")
        names.append(name)  # add the name to the name list
        n = n + 1  # increase counter

    if debug:  # if we should output debug information
        # print final progress bar
        print(libprogress.genfullbar(prg=count))
    return names  # return the name list



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="libnamegen",
    version="3.1",
    author="BBaoVanC",
    author_email="bbaovanc@protonmail.com",
    description="Library containing name generation methods",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/BBaoVanC/libnamegen",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    install_requires=[
          'libprogress<3.0.2',
          'liblistloader==1.0',
    ],
    python_requires='>=3.6',
)



#!/usr/bin/env python3
"""
Name Generator Method Package.

by BBaoVanC

!!! THIS PACKAGE WILL NOT WORK IF YOUR PROGRAM IS IN libnamegen/ !!!
This is a package which contains the various name generation methods used in
https://github.com/BBaoVanC/NameGenerator

Copyright (C) 2020 BBaoVanC
"""

# Imports
import libnamegen.classic  # NOQA
import libnamegen.random  # NOQA



#!/usr/bin/env python3
"""
Classic Generator.

by BBaoVanC

The classic method for NameGenerator

Examples:
    TheAssignmentanatorifier_90
    Coinifier_313
    COMPONENTGUY290

Copyright (C) 2020 BBaoVanC
"""

# Imports
# import os
import random
import libprogress
import liblistloader.desiquintans_nounlist


# Generation method
def gen(count=1, debug=False):
    """
    Generate names using the classic method.

    Arguments:
    count -- the amount of names to generate (default 1)
    debug -- whether debug should be printed (default False)
    """
    words = liblistloader.desiquintans_nounlist.words
    wsuffixes = ["ator", "man", "guy", "ifier", "anator", ""]  # suffixes
    wprefixes = ["Mr", "The", ""]  # prefixes
    names = list()  # initialize the names list variable
    # vowels = ['a', 'e', 'i', 'o', 'u']
    # vowels2 = ['a', 'e', 'i', 'o', 'u', 'y']
    vowels3 = ['a', 'i', 'o', 'u']  # custom vowel list
    n = 1  # initialize loop counter
    while count >= n:  # name generation loop
        word_pre = random.choice(words)  # nosec
        word_pre = word_pre.capitalize()  # capitalize the first letter
        wprefix = random.choice(wprefixes)  # nosec | choose a random prefix
        wsuffix = random.choice(wsuffixes)  # nosec | choose a random suffix
        wsuffix2 = wsuffix  # initialize wsuffix2 variable
        if wsuffix == "ator" or wsuffix == "anator":  # if the suffix is either
            if random.choice([True, False, False]):  # nosec | 1/3 chance
                wsuffix2 = wsuffix + "ifier"  # add the extra suffix of "ifier"

        # if we should make the name all caps
        caps = random.choice([True, False, False, False])  # nosec 1/4 chance
        if caps:  # if we are going to make it all caps
            wprefix = wprefix.upper()  # set the prefix to all caps
            word_pre = word_pre.upper()  # set the word to all caps
            wsuffix2 = wsuffix2.upper()  # set the suffix to all caps
            if len(wprefix) > 0:  # if there is a prefix
                wprefix = wprefix + "_"  # underscore at the end of the prefix

        if word_pre[-1] in vowels3:  # if the word ends in aiouy
            if wsuffix == 'ator' or wsuffix == 'anator':  # grammar fix
                wsuffix = 'nator'  # set the suffix to "nator"

        # create a string 'word' which adds the 3 parts together
        word = str(wprefix) + str(word_pre) + str(wsuffix2)
        # choose if there should be an underscore before the number at the end
        space = random.choice(["_", "", ""])  # nosec
        # choose a random number to have at the end
        number = random.randint(0, 999)  # nosec
        # puts together the different parts of the username
        name = str(word) + str(space) + str(number)
        if debug:  # if we should output debug information
            # print progress bar
            print(libprogress.genbar(curprg=n-1, maxprg=count), end="\r")
        names.append(name)  # add name to list of generated names
        n = n + 1  # increases our loop counter

    if debug:  # if we should output debug information
        # print last progress bar
        print(libprogress.genfullbar(prg=count))
    return names  # return the generated names
